==> cmb-superbuild-v21.05.0.zip: cmb-superbuild-v21.05.0/.gitlab/ci/gitlab_ci.cmake <==
if (NOT DEFINED "ENV{GITLAB_CI}")
  message(FATAL_ERROR
    "This script assumes it is being run inside of GitLab-CI")
endif ()

# Set up the source and build paths.
set(CTEST_SOURCE_DIRECTORY "$ENV{CI_PROJECT_DIR}")
set(CTEST_BINARY_DIRECTORY "${CTEST_SOURCE_DIRECTORY}/build")

if ("$ENV{CMAKE_CONFIGURATION}" STREQUAL "")
  message(FATAL_ERROR
    "The CMAKE_CONFIGURATION environment variable is required to know what "
    "cache initialization file to use.")
endif ()

# Set the build metadata.
set(CTEST_BUILD_NAME "$ENV{CI_PROJECT_NAME}-$ENV{CMAKE_CONFIGURATION}")
set(CTEST_SITE "gitlab-ci")

# Default to Release builds.
if (NOT "$ENV{CMAKE_BUILD_TYPE}" STREQUAL "")
  set(CTEST_BUILD_CONFIGURATION "$ENV{CMAKE_BUILD_TYPE}")
endif ()
if (NOT CTEST_BUILD_CONFIGURATION)
  set(CTEST_BUILD_CONFIGURATION "Release")
endif ()

# Default to using Ninja.
if (NOT "$ENV{CMAKE_GENERATOR}" STREQUAL "")
  set(CTEST_CMAKE_GENERATOR "$ENV{CMAKE_GENERATOR}")
endif ()
if (NOT CTEST_CMAKE_GENERATOR)
  set(CTEST_CMAKE_GENERATOR "Ninja")
endif ()

if ("$ENV{CMAKE_CONFIGURATION}" MATCHES "aeva")
  set(ctest_submit_to_aeva TRUE)
endif ()

# Determine the track to submit to.
set(ctest_track "Experimental")
if (ctest_submit_to_aeva)
  if (NOT "$ENV{CI_MERGE_REQUEST_ID}" STREQUAL "")
    set(ctest_track "aeva-package-merge-requests")
  elseif ("$ENV{CI_PROJECT_PATH}" STREQUAL "cmb/cmb-superbuild")
    set(ctest_track "aeva-package-master")
  endif ()
else ()
  if (NOT "$ENV{CI_MERGE_REQUEST_ID}" STREQUAL "")
    if ("$ENV{CI_MERGE_REQUEST_TARGET_BRANCH_NAME}" STREQUAL "master")
      set(ctest_track "buildbot-packages")
    elseif ("$ENV{CI_MERGE_REQUEST_TARGET_BRANCH_NAME}" STREQUAL "release")
      set(ctest_track "buildbot-packages-release")
    endif ()
  elseif ("$ENV{CI_PROJECT_PATH}" STREQUAL "cmb/cmb-superbuild")
    if ("$ENV{CI_COMMIT_REF_NAME}" STREQUAL "master")
      set(ctest_track "master-packages")
    elseif ("$ENV{CI_COMMIT_REF_NAME}" STREQUAL "release")
      set(ctest_track "release-packages")
    endif ()
  endif ()
endif ()

==> cmb-superbuild-v21.07.0.zip: cmb-superbuild-v21.07.0/.gitlab/ci/gitlab_ci.cmake <==
if (NOT DEFINED "ENV{GITLAB_CI}")
  message(FATAL_ERROR
    "This script assumes it is being run inside of GitLab-CI")
endif ()

# Set up the source and build paths.
set(CTEST_SOURCE_DIRECTORY "$ENV{CI_PROJECT_DIR}")
set(CTEST_BINARY_DIRECTORY "${CTEST_SOURCE_DIRECTORY}/build")

if ("$ENV{CMAKE_CONFIGURATION}" STREQUAL "")
  message(FATAL_ERROR
    "The CMAKE_CONFIGURATION environment variable is required to know what "
    "cache initialization file to use.")
endif ()

# Set the build metadata.
set(CTEST_BUILD_NAME "$ENV{CI_PROJECT_NAME}-$ENV{CMAKE_CONFIGURATION}")
set(CTEST_SITE "gitlab-ci")

# Default to Release builds.
if (NOT "$ENV{CMAKE_BUILD_TYPE}" STREQUAL "")
  set(CTEST_BUILD_CONFIGURATION "$ENV{CMAKE_BUILD_TYPE}")
endif ()
if (NOT CTEST_BUILD_CONFIGURATION)
  set(CTEST_BUILD_CONFIGURATION "Release")
endif ()

# Default to using Ninja.
if (NOT "$ENV{CMAKE_GENERATOR}" STREQUAL "")
  set(CTEST_CMAKE_GENERATOR "$ENV{CMAKE_GENERATOR}")
endif ()
if (NOT CTEST_CMAKE_GENERATOR)
  set(CTEST_CMAKE_GENERATOR "Ninja")
endif ()

if ("$ENV{CMAKE_CONFIGURATION}" MATCHES "aeva")
  set(ctest_submit_to_aeva TRUE)
elseif ("$ENV{CMAKE_CONFIGURATION}" MATCHES "truchas")
  set(ctest_submit_to_truchas TRUE)
elseif ("$ENV{CMAKE_CONFIGURATION}" MATCHES "ace3p")
  set(ctest_submit_to_ace3p TRUE)
endif ()

# Determine the track to submit to.
set(ctest_track "Experimental")
if (ctest_submit_to_aeva)
  if (NOT "$ENV{CI_MERGE_REQUEST_ID}" STREQUAL "")
    set(ctest_track "aeva-package-merge-requests")
  elseif ("$ENV{CI_PROJECT_PATH}" STREQUAL "cmb/cmb-superbuild")
    set(ctest_track "aeva-package-master")
  endif ()
elseif (ctest_submit_to_ace3p)
  if (NOT "$ENV{CI_MERGE_REQUEST_ID}" STREQUAL "")
    set(ctest_track "buildbot-packages")
  elseif ("$ENV{CI_PROJECT_PATH}" STREQUAL "cmb/cmb-superbuild")
    set(ctest_track "master-packages-ace3p")
  endif ()
elseif (ctest_submit_to_truchas)
  if (NOT "$ENV{CI_MERGE_REQUEST_ID}" STREQUAL "")
    set(ctest_track "buildbot-packages")
  elseif ("$ENV{CI_PROJECT_PATH}" STREQUAL "cmb/cmb-superbuild")
    set(ctest_track "master-packages-truchas")
  endif ()
else ()
  if (NOT "$ENV{CI_MERGE_REQUEST_ID}" STREQUAL "")
    if ("$ENV{CI_MERGE_REQUEST_TARGET_BRANCH_NAME}" STREQUAL "master")
      set(ctest_track "buildbot-packages")
    elseif ("$ENV{CI_MERGE_REQUEST_TARGET_BRANCH_NAME}" STREQUAL "release")
      set(ctest_track "buildbot-packages-release")
    endif ()
  elseif ("$ENV{CI_PROJECT_PATH}" STREQUAL "cmb/cmb-superbuild")
    if ("$ENV{CI_COMMIT_REF_NAME}" STREQUAL "master")
      set(ctest_track "master-packages")
    elseif ("$ENV{CI_COMMIT_REF_NAME}" STREQUAL "release")
      set(ctest_track "release-packages")
    endif ()
  endif ()
endif ()
